@@ -559,8 +559,10 @@ def send_error_report(operation, error):
         .format("fup-services", APIGW, operation, error)
     )
     sender = "api-gateway@si.blueline.mg"
-    # destinations = ["dev@si.blueline.mg", "sysadmin@si.blueline.mg"]
-    destinations = ["yona.rasolonjatovo@staff.blueline.mg",]
+    destinations = [
+        "dev@si.blueline.mg",
+        "sysadmin@si.blueline.mg"
+    ]
     content = MIMEText(message, 'plain', 'utf-8')
 
     msg = MIMEMultipart('related')
@@ -572,27 +574,12 @@ def send_error_report(operation, error):
 
     smtp = smtplib.SMTP()
     smtp.connect("smtp.blueline.mg", port=10026)
-    # smtp = smtplib.SMTP('localhost')
     smtp.sendmail(sender, destinations, msg.as_string())
     smtp.quit()
 
     LOGS.logger.info(
         "Email: '{}' sent to {}".format(msg['Subject'], destinations))
 
-    # message = (
-    #     "Service: {} [{}]\n\n"
-    #     "Affected operation: {}\n\n"
-    #     "Error: {}"
-    #     .format("fup-services", APIGW, operation, error)
-    # )
-    # destinations = ["dev@si.blueline.mg", "sysadmin@si.blueline.mg"]
-    #
-    # send_email(
-    #     destinations=destinations,
-    #     subject="fup-services process error",
-    #     message=message
-    # )
-
 
 def send_email(destinations, subject, message, attachment=None):
     """
@@ -635,6 +622,5 @@ def send_email(destinations, subject, message, attachment=None):
 
     LOGS.logger.info(
         "Email: '{}' sent to {}".format(msg['Subject'], destinations))
-    smtp.quit()
 
 # EOF
